@@ -93,7 +93,7 @@ def create_where(equality_constraints, interval_constraints):
     res = []
     for name in interval_constraints:
         values = interval_constraints[name]
-        tmp = [(name, value1, value2) for value1, value2 in values]
+        tmp = [(name, value1, value2) for value1, value2 in values if value1 or value2]
         print(tmp)
         ans = ' or '.join([f"{name} between {value1} and {value2}" if value1 and value2 else
                             f"{name} >= {value1}" if value1 else
